@@ -886,7 +886,13 @@ def main():
     if options.output_dir:
         output_path = options.output_dir
     else:
-        output_path = path + "/merged"
+        if len(path) == 0:
+            # If running in current directory
+            # TODO: clean this up, don't want to save to /merged in root fs
+            output_path = path + "gml"
+        else:
+            output_path = path + "/gml"
+
 
     if options.dataset_only:
         output_path += "_dataset_only"
@@ -904,6 +910,7 @@ def main():
     if not os.path.isdir(output_path):
         os.mkdir(output_path)
 
+    logger.info("Saving to folder: %s" % output_path)
     # and create cache directory for pickle files
     pickle_dir = path + "/cache"
     if not os.path.isdir(pickle_dir):
